# Example Package

[GetHub](https://github.com/DrSudoSaeed/)

Library to search and download your favorite songs in the best quality :)

This library is always updated. Wait for new versions soon!

To use, install the library according to the instructions!


To download, just copy one of the links he gave you when searching for the song and put it here.
Note that auto is mandatory, you must put it in the second parameter!
If auto is True, the song will be downloaded automatically.
If auto is equal to False, you will only receive a direct link to the song.

I hope you enjoy this library and introduce it to your friends :)

[Telegram](https://t.me/sudosaeed)
[instagram](https://www.instagram.com/sudosaeed/)


**Follow the steps below to use:**

```

from SearchMusic import *

search("آرون+افشار")  # Replace the music name with fast

download("https://music-fa.com/download-song/50970/",auto=True)

# To download, just copy one of the links it gave you when searching for the song and paste it here

```